DemoPackage Package
===================

:mod:`DemoPackage` Package
--------------------------

.. automodule:: DemoPackage.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: DemoPackage.utils
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    DemoPackage.tests

